@@ -40,53 +40,60 @@ The C<new> constructor takes no arguments and creates a new parser/model object.
 
 use 5.008005;
 use Mouse            0.61;
-use Params::Util     1.00 ();
-use FBP::Project          ();
-use FBP::Dialog           ();
-use FBP::BitmapButton     ();
-use FBP::BoxSizer         ();
-use FBP::Button           ();
-use FBP::CheckBox         ();
-use FBP::Choice           ();
-use FBP::ComboBox         ();
-use FBP::ColourPickerCtrl ();
-use FBP::CustomControl    ();
-use FBP::DirPickerCtrl    ();
-use FBP::FilePickerCtrl   ();
-use FBP::FlexGridSizer    ();
-use FBP::FontPickerCtrl   ();
-use FBP::FormPanel        ();
-use FBP::Frame            ();
-use FBP::Gauge            ();
-use FBP::GridSizer        ();
-use FBP::HtmlWindow       ();
-use FBP::HyperLink        ();
-use FBP::Listbook         ();
-use FBP::ListbookPage     ();
-use FBP::ListBox          ();
-use FBP::ListCtrl         ();
-use FBP::Menu             ();
-use FBP::MenuBar          ();
-use FBP::MenuItem         ();
-use FBP::MenuSeparator    ();
-use FBP::Panel            ();
-use FBP::RadioBox         ();
-use FBP::SearchCtrl       ();
-use FBP::SizerItem        ();
-use FBP::Spacer           ();
-use FBP::SpinCtrl         ();
-use FBP::SplitterItem     ();
-use FBP::SplitterWindow   ();
-use FBP::StaticBoxSizer   ();
-use FBP::StaticText       ();
-use FBP::StaticLine       ();
-use FBP::StatusBar        ();
-use FBP::TextCtrl         ();
-use FBP::Tool             ();
-use FBP::ToolBar          ();
-use FBP::ToolSeparator    ();
+use Params::Util         1.00 ();
+use FBP::Project              ();
+use FBP::Dialog               ();
+use FBP::BitmapButton         ();
+use FBP::BoxSizer             ();
+use FBP::Button               ();
+use FBP::CalendarCtrl         ();
+use FBP::CheckBox             ();
+use FBP::Choice               ();
+use FBP::ComboBox             ();
+use FBP::ColourPickerCtrl     ();
+use FBP::CustomControl        ();
+use FBP::DatePickerCtrl       ();
+use FBP::DirPickerCtrl        ();
+use FBP::FilePickerCtrl       ();
+use FBP::FlexGridSizer        ();
+use FBP::FontPickerCtrl       ();
+use FBP::FormPanel            ();
+use FBP::Frame                ();
+use FBP::Gauge                ();
+use FBP::GridSizer            ();
+use FBP::HtmlWindow           ();
+use FBP::HyperLink            ();
+use FBP::Listbook             ();
+use FBP::ListbookPage         ();
+use FBP::ListBox              ();
+use FBP::ListCtrl             ();
+use FBP::Menu                 ();
+use FBP::MenuBar              ();
+use FBP::MenuItem             ();
+use FBP::MenuSeparator        ();
+use FBP::Panel                ();
+use FBP::RadioBox             ();
+use FBP::ScrolledWindow       ();
+use FBP::SearchCtrl           ();
+use FBP::SizerItem            ();
+use FBP::Slider               ();
+use FBP::Spacer               ();
+use FBP::SpinCtrl             ();
+use FBP::SplitterItem         ();
+use FBP::SplitterWindow       ();
+use FBP::StaticBitmap         ();
+use FBP::StaticBoxSizer       ();
+use FBP::StaticText           ();
+use FBP::StaticLine           ();
+use FBP::StatusBar            ();
+use FBP::StdDialogButtonSizer ();
+use FBP::TextCtrl             ();
+use FBP::ToggleButton         ();
+use FBP::Tool                 ();
+use FBP::ToolBar              ();
+use FBP::ToolSeparator        ();
 
-our $VERSION = '0.32';
+our $VERSION = '0.33';
 
 extends 'FBP::Object';
 with    'FBP::Children';
