@@ -1,10 +1,16 @@
 package FBP::BitmapButton;
 
 use Mouse;
+use FBP::Control;
 
-our $VERSION = '0.32';
+our $VERSION = '0.33';
 
-extends 'FBP::Button';
+extends 'FBP::Control';
+
+has style => (
+	is  => 'ro',
+	isa => 'Str',
+);
 
 has bitmap => (
 	is  => 'ro',
@@ -31,4 +37,9 @@ has hover => (
 	isa => 'Str',
 );
 
+has OnButtonClick => (
+	is  => 'ro',
+	isa => 'Str',
+);
+
 1;
