@@ -7,60 +7,67 @@ use Params::Util   ();
 use XML::SAX::Base ();
 use FBP            ();
 
-our $VERSION = '0.32';
+our $VERSION = '0.33';
 our @ISA     = 'XML::SAX::Base';
 
 # Object XML class to Perl class mapping
 my %OBJECT_CLASS = (
-	Project            => 'FBP::Project',
-	Dialog             => 'FBP::Dialog',
-	Frame              => 'FBP::Frame',
-	Panel              => 'FBP::FormPanel',
+	Project                => 'FBP::Project',
+	Dialog                 => 'FBP::Dialog',
+	Frame                  => 'FBP::Frame',
+	Panel                  => 'FBP::FormPanel',
 
 	# Direct Mappings
-	wxBitmapButton     => 'FBP::BitmapButton',
-	wxBoxSizer         => 'FBP::BoxSizer',
-	wxButton           => 'FBP::Button',
-	wxCheckBox         => 'FBP::CheckBox',
-	wxChoice           => 'FBP::Choice',
-	wxComboBox         => 'FBP::ComboBox',
-	wxColourPickerCtrl => 'FBP::ColourPickerCtrl',
-	wxDirPickerCtrl    => 'FBP::DirPickerCtrl',
-	wxFilePickerCtrl   => 'FBP::FilePickerCtrl',
-	wxFlexGridSizer    => 'FBP::FlexGridSizer',
-	wxFontPickerCtrl   => 'FBP::FontPickerCtrl',
-	wxGauge            => 'FBP::Gauge',
-	wxGridSizer        => 'FBP::GridSizer',
-	wxHtmlWindow       => 'FBP::HtmlWindow',
-	wxHyperlinkCtrl    => 'FBP::HyperLink',
-	wxListbook         => 'FBP::Listbook',
-	wxListBox          => 'FBP::ListBox',
-	wxListCtrl         => 'FBP::ListCtrl',
-	wxMenu             => 'FBP::Menu',
-	wxMenuBar          => 'FBP::MenuBar',
-	wxMenuItem         => 'FBP::MenuItem',
-	wxPanel            => 'FBP::Panel',
-	wxRadioBox         => 'FBP::RadioBox',
-	wxSearchCtrl       => 'FBP::SearchCtrl',
-	wxSpinCtrl         => 'FBP::SpinCtrl',
-	wxSplitterWindow   => 'FBP::SplitterWindow',
-	wxStaticBoxSizer   => 'FBP::StaticBoxSizer',
-	wxStaticText       => 'FBP::StaticText',
-	wxStaticLine       => 'FBP::StaticLine',
-	wxStatusBar        => 'FBP::StatusBar',
-	wxTextCtrl         => 'FBP::TextCtrl',
-	wxToolBar          => 'FBP::ToolBar',
+	wxBitmapButton         => 'FBP::BitmapButton',
+	wxBoxSizer             => 'FBP::BoxSizer',
+	wxButton               => 'FBP::Button',
+	wxCalendarCtrl         => 'FBP::CalendarCtrl',
+	wxCheckBox             => 'FBP::CheckBox',
+	wxChoice               => 'FBP::Choice',
+	wxComboBox             => 'FBP::ComboBox',
+	wxColourPickerCtrl     => 'FBP::ColourPickerCtrl',
+	wxDatePickerCtrl       => 'FBP::DatePickerCtrl',
+	wxDirPickerCtrl        => 'FBP::DirPickerCtrl',
+	wxFilePickerCtrl       => 'FBP::FilePickerCtrl',
+	wxFlexGridSizer        => 'FBP::FlexGridSizer',
+	wxFontPickerCtrl       => 'FBP::FontPickerCtrl',
+	wxGauge                => 'FBP::Gauge',
+	wxGridSizer            => 'FBP::GridSizer',
+	wxHtmlWindow           => 'FBP::HtmlWindow',
+	wxHyperlinkCtrl        => 'FBP::HyperLink',
+	wxListbook             => 'FBP::Listbook',
+	wxListBox              => 'FBP::ListBox',
+	wxListCtrl             => 'FBP::ListCtrl',
+	wxMenu                 => 'FBP::Menu',
+	wxMenuBar              => 'FBP::MenuBar',
+	wxMenuItem             => 'FBP::MenuItem',
+	wxPanel                => 'FBP::Panel',
+	wxRadioBox             => 'FBP::RadioBox',
+	wxScrolledWindow       => 'FBP::ScrolledWindow',
+	wxSearchCtrl           => 'FBP::SearchCtrl',
+	wxSlider               => 'FBP::Slider',
+	wxSpinCtrl             => 'FBP::SpinCtrl',
+	wxSplitterWindow       => 'FBP::SplitterWindow',
+	wxStaticBitmap         => 'FBP::StaticBitmap',
+	wxStaticBoxSizer       => 'FBP::StaticBoxSizer',
+	wxStaticText           => 'FBP::StaticText',
+	wxStaticLine           => 'FBP::StaticLine',
+	wxStatusBar            => 'FBP::StatusBar',
+	wxStdDialogButtonSizer => 'FBP::StdDialogButtonSizer',
+	wxTextCtrl             => 'FBP::TextCtrl',
+	wxToggleButton         => 'FBP::ToggleButton',
+	wxToolBar              => 'FBP::ToolBar',
 
 	# Special Mappings
-	submenu            => 'FBP::Menu',
-	listbookpage       => 'FBP::ListbookPage',
-	sizeritem          => 'FBP::SizerItem',
-	separator          => 'FBP::MenuSeparator',
-	spacer             => 'FBP::Spacer',
-	splitteritem       => 'FBP::SplitterItem',
-	tool               => 'FBP::Tool',
-	toolSeparator      => 'FBP::ToolSeparator',
-	CustomControl      => 'FBP::CustomControl',
+	submenu                => 'FBP::Menu',
+	listbookpage           => 'FBP::ListbookPage',
+	sizeritem              => 'FBP::SizerItem',
+	separator              => 'FBP::MenuSeparator',
+	spacer                 => 'FBP::Spacer',
+	splitteritem           => 'FBP::SplitterItem',
+	tool                   => 'FBP::Tool',
+	toolSeparator          => 'FBP::ToolSeparator',
+	CustomControl          => 'FBP::CustomControl',
 );
 
 
