@@ -11,7 +11,7 @@ FBP::Window - Base class for all graphical wxWindow objects
 use Mouse;
 use Scalar::Util ();
 
-our $VERSION = '0.32';
+our $VERSION = '0.33';
 
 extends 'FBP::Object';
 with    'FBP::Children';
@@ -314,6 +314,33 @@ sub header {
 	return;
 }
 
+
+
+
+
+######################################################################
+# Events
+
+has OnEraseBackground => (
+	is  => 'ro',
+	isa => 'Str',
+);
+
+has OnPaint => (
+	is  => 'ro',
+	isa => 'Str',
+);
+
+has OnSize => (
+	is  => 'ro',
+	isa => 'Str',
+);
+
+has OnUpdateUI => (
+	is  => 'ro',
+	isa => 'Str',
+);
+
 1;
 
 =pod
